@@ -7,6 +7,7 @@ import org.gcube.portlets.user.td.gwtservice.shared.tr.ColumnData;
 import org.gcube.portlets.user.tdtemplate.shared.SPECIAL_CATEGORY_TYPE;
 import org.gcube.portlets.user.tdtemplate.shared.TdTColumnCategory;
 import org.gcube.portlets.user.tdtemplate.shared.TdTDataType;
+import org.gcube.portlets.user.tdtemplate.shared.TdTFormatReference;
 
 /**
  * @author Francesco Mangiacrapa francesco.mangiacrapa@isti.cnr.it
@@ -40,5 +41,9 @@ public interface ColumnDefinition {
 	 * 
 	 */
 	String getTimePeriod();
+	
+	TdTFormatReference getTimePeriodFormat();
+	
+	TdTFormatReference getSelectedDataTypeFormat();
 
 }
