@@ -9,6 +9,7 @@ import java.util.Calendar;
 import java.util.Collection;
 import java.util.HashMap;
 import java.util.List;
+import java.util.Map;
 
 import org.gcube.data.analysis.tabulardata.commons.templates.model.Template;
 import org.gcube.data.analysis.tabulardata.commons.templates.model.TemplateCategory;
@@ -17,12 +18,15 @@ import org.gcube.data.analysis.tabulardata.commons.templates.model.columns.Colum
 import org.gcube.data.analysis.tabulardata.commons.templates.model.columns.ColumnDescription;
 import org.gcube.data.analysis.tabulardata.commons.templates.model.columns.TemplateColumn;
 import org.gcube.data.analysis.tabulardata.commons.utils.DimensionReference;
+import org.gcube.data.analysis.tabulardata.commons.utils.FormatReference;
 import org.gcube.data.analysis.tabulardata.commons.utils.Licence;
 import org.gcube.data.analysis.tabulardata.commons.utils.LocaleReference;
 import org.gcube.data.analysis.tabulardata.commons.utils.TimeDimensionReference;
 import org.gcube.data.analysis.tabulardata.commons.webservice.types.OnRowErrorAction;
 import org.gcube.data.analysis.tabulardata.commons.webservice.types.TemplateDescription;
 import org.gcube.data.analysis.tabulardata.expression.Expression;
+import org.gcube.data.analysis.tabulardata.model.DataTypeFormats;
+import org.gcube.data.analysis.tabulardata.model.ValueFormat;
 import org.gcube.data.analysis.tabulardata.model.datatype.DataType;
 import org.gcube.data.analysis.tabulardata.model.metadata.Locales;
 import org.gcube.data.analysis.tabulardata.model.metadata.common.TableDescriptorMetadata;
@@ -53,7 +57,10 @@ import org.gcube.portlets.user.tdtemplate.shared.TdFlowModel;
 import org.gcube.portlets.user.tdtemplate.shared.TdLicenceModel;
 import org.gcube.portlets.user.tdtemplate.shared.TdTColumnCategory;
 import org.gcube.portlets.user.tdtemplate.shared.TdTDataType;
+import org.gcube.portlets.user.tdtemplate.shared.TdTFormatReference;
+import org.gcube.portlets.user.tdtemplate.shared.TdTFormatReferenceIndexer;
 import org.gcube.portlets.user.tdtemplate.shared.TdTTemplateType;
+import org.gcube.portlets.user.tdtemplate.shared.TdTTimePeriod;
 import org.gcube.portlets.user.tdtemplate.shared.TdTemplateDefinition;
 import org.gcube.portlets.user.tdtemplate.shared.TdTemplateUpdater;
 import org.gcube.portlets.user.tdtemplate.shared.TemplateExpression;
@@ -93,17 +100,6 @@ public class ConverterToTdTemplateModel {
 	
 	public static List<ViolationDescription> getTemplateCategoryConstraint(TemplateCategory cat) {
 
-		/*switch (cat) {
-		
-			case CODELIST: return "A Codelist must have one (and only one) Code column";
-	
-			case DATASET: return "A Dataset must have at least one dimension (reference to a CodeList) and at least one value column";
-			
-			case GENERIC: return "";
-			
-			default: return "";
-		}*/
-		
 		List<ViolationDescription> violations  = new ArrayList<ViolationDescription>();
 		
 		ColumnCategoryTemplateValidator templateValidator = null;
@@ -184,6 +180,18 @@ public class ConverterToTdTemplateModel {
 		
 	}
 	
+	public static List<TdTFormatReference> getTdTFormatReferences(Class<? extends DataType> dataType){
+
+		List<ValueFormat> formats = DataTypeFormats.getFormatsPerDataType(dataType);
+
+		List<TdTFormatReference> tdtFormats = new ArrayList<TdTFormatReference>(formats.size());
+		for (ValueFormat valueFormat : formats) {
+			tdtFormats.add(new TdTFormatReference(valueFormat.getId(), valueFormat.getExample()));
+		}
+		
+		return tdtFormats;
+	}
+	
 	
 	/**
 	 * 
@@ -195,10 +203,15 @@ public class ConverterToTdTemplateModel {
 		if(col==null)
 			throw new Exception("ColumnCategory is null");
 		
+//		if(col.isReferenceRequired()){
+//			col.getReferenceClass();
+//			return new TdTColumnCategory(col.name(), col.name()  )
+//		}
 		return new TdTColumnCategory(col.name(), col.name());
-		
 	}
 	
+
+	
 	public static List<TdTDataType> getTdTDataTypeFromListDataType(List<Class<? extends DataType>> dataTypes) throws Exception{
 		
 		List<TdTDataType> listTdTDataType  = new ArrayList<TdTDataType>();
@@ -229,8 +242,19 @@ public class ConverterToTdTemplateModel {
 		
 		logger.info("\t \t DataType: "+dataType + " purged simple name: " +purgedSimpleName);
 		
+		List<TdTFormatReference> formats = getTdTFormatReferences(dataType);
+		
+		if(formats!=null){
+			TdTFormatReferenceIndexer indexer = new TdTFormatReferenceIndexer();
+			
+			for (TdTFormatReference tdTFormatReference : formats) {
+				indexer.putFormat(tdTFormatReference);
+			}
+			
+			return new TdTDataType(dataType.getName(), purgedSimpleName, indexer);
+		}
+		
 		return new TdTDataType(dataType.getName(), purgedSimpleName);
-
 	}
 	
 	public List<String> getOnErrorActions(){
@@ -283,13 +307,13 @@ public class ConverterToTdTemplateModel {
 					TdTDataType tdDataType = null;
 					//Value type conversion
 					Class<? extends DataType> sValueType = templateColumn.getValueType(); //SERVER
+
 					try {
 						tdDataType = getTdTDataTypeFromDataType(sValueType); //WIDGET
 					}catch (Exception e) {
 						logger.error("Errror on converting data type, skypping value",e);
 					}
 					
-					
 					//EXPRESSION TODO??
 					List<Expression> sExpression = templateColumn.getExpressions();
 					List<TemplateExpression> listExpressionExtend = null;
@@ -345,31 +369,47 @@ public class ConverterToTdTemplateModel {
 	 */
 	public static TdColumnDefinition settingSpecificReference(TemplateColumn<?> templateColumn, TdColumnDefinition tdColumn, TemplateService service){
 		
-		if(templateColumn==null)
+		if(templateColumn==null || templateColumn.getReference()==null)
 			return tdColumn;
 
-		Object refence = templateColumn.getReference();
+		Object reference = templateColumn.getReference();
 		
 		//USED IN CODELIST
-		if(refence instanceof LocaleReference){
+		if(reference instanceof LocaleReference){
 			logger.info("Found column reference as LocaleReference..");
-			LocaleReference locale = (LocaleReference) templateColumn.getReference();
+			LocaleReference locale = (LocaleReference) reference;
 			if(locale!=null){
 				logger.info("Setting locale as "+locale.getLocale());
 				tdColumn.setLocale(locale.getLocale());
 //				tdColumn.setSpecialCategoryType(SPECIAL_CATEGORY_TYPE.CODENAME);
 			}
-		}else if(refence instanceof TimeDimensionReference){
+		}else if(reference instanceof TimeDimensionReference){
 			logger.info("Found column reference as TimeDimensionReference..");
-			TimeDimensionReference timeDimension = (TimeDimensionReference) templateColumn.getReference();
+			TimeDimensionReference timeDimension = (TimeDimensionReference) reference;
 			if(timeDimension!=null && timeDimension.getPeriod()!=null){
-				logger.info("Setting timeDimension as "+timeDimension.getPeriod().name());
-				tdColumn.setTimePeriod(timeDimension.getPeriod().name());
+
+				Map<String, String> timeValues = new HashMap<String, String>();
+				
+				if(timeDimension.getFormatIdentifier()!=null){
+					ValueFormat valueFormat = timeDimension.getPeriod().getTimeFormatById(timeDimension.getFormatIdentifier());
+					if(valueFormat!=null)
+						timeValues.put(valueFormat.getId(), valueFormat.getExample());
+				}
+				
+				TdTTimePeriod tt = new TdTTimePeriod(timeDimension.getPeriod().name(), timeValues);
+				logger.info("Setting TdTTimePeriod as "+tt);
+				tdColumn.setTimePeriod(tt);
 //				tdColumn.setSpecialCategoryType(SPECIAL_CATEGORY_TYPE.TIMEDIMENSION);
 			}
-		}else if(refence instanceof DimensionReference){
+		}else if(reference instanceof FormatReference){
+			
+			FormatReference formatReference = (FormatReference) reference;
+			ValueFormat valueFormat = DataTypeFormats.getFormatPerId(templateColumn.getValueType(), formatReference.getFormatIdentifier());
+			tdColumn.getDataType().setReference(new TdTFormatReference(valueFormat.getId(), valueFormat.getExample()));
+			
+		}else if(reference instanceof DimensionReference){
 			logger.info("Found column reference as DimensionReference..");
-			DimensionReference dimension = (DimensionReference) templateColumn.getReference();
+			DimensionReference dimension = (DimensionReference) reference;
 			if(dimension!=null){
 				
 				String columnId = dimension.getColumnId()!=null?dimension.getColumnId().getValue():null;
@@ -410,8 +450,6 @@ public class ConverterToTdTemplateModel {
 		}
 		
 		return tdColumn;
-		
-		
 	}
 	
 	public static List<String> getAllowedLocales(){
@@ -421,13 +459,18 @@ public class ConverterToTdTemplateModel {
 	/**
 	 * @return
 	 */
-	public static List<String> getTimeDimensionPeriodTypes() {
+	public static List<TdTTimePeriod> getTimeDimensionPeriodTypes() {
 		
-		List<String> listDataTypes = new ArrayList<String>(PeriodType.values().length);
-		for (PeriodType period : PeriodType.values())
-			listDataTypes.add(period.name());
-		
-		return listDataTypes;
+		List<TdTTimePeriod> listTimePeriods = new ArrayList<TdTTimePeriod>(PeriodType.values().length);
+		for (PeriodType period : PeriodType.values()){
+			
+			Map<String, String> valuesFormat = new HashMap<String, String>(period.getAcceptedFormats().size());
+			for (ValueFormat vf : period.getAcceptedFormats()) {
+				valuesFormat.put(vf.getId(), vf.getExample());
+			}
+			listTimePeriods.add(new TdTTimePeriod(period.name(),valuesFormat));
+		}
+		return listTimePeriods;
 	}
 	
 	public static List<TdLicenceModel> getLicences(){
