@@ -13,6 +13,7 @@ import org.gcube.data.analysis.tabulardata.commons.templates.model.TemplateCateg
 import org.gcube.data.analysis.tabulardata.commons.templates.model.actions.finals.AddToFlowAction;
 import org.gcube.data.analysis.tabulardata.commons.templates.model.actions.finals.DuplicateBehaviour;
 import org.gcube.data.analysis.tabulardata.commons.templates.model.columns.ColumnCategory;
+import org.gcube.data.analysis.tabulardata.commons.utils.FormatReference;
 import org.gcube.data.analysis.tabulardata.commons.utils.Licence;
 import org.gcube.data.analysis.tabulardata.commons.utils.LocaleReference;
 import org.gcube.data.analysis.tabulardata.commons.webservice.types.OnRowErrorAction;
@@ -109,7 +110,7 @@ public class ConverterToTemplateServiceModel {
 			return PeriodType.valueOf(periodName);
 			
 		}catch (Exception e) {
-			throw new Exception("The PeriodType "+ periodName+" is not a value of "+PeriodType.class);
+			throw new Exception("The PeriodType "+ periodName+" is not a valid fromName of "+PeriodType.class);
 		}
 		
 	}
@@ -203,6 +204,18 @@ public class ConverterToTemplateServiceModel {
 		return null;
 	}
 	
+	/**
+	 * @param dataType
+	 * @return 
+	 */
+	public static FormatReference tdTdTFormatRefereceToFormatReference(TdTDataType dataType) {
+		
+		if(dataType.getReference()!=null){
+			return new FormatReference(dataType.getReference().getId());
+		}
+		return null;
+	}
+	
 	/**
 	 * 
 	 * @param columnCategoryName
